@@ -207,7 +207,7 @@ class Blog(object):
             return match.group(0)
 
         content = self.markdown_image_pattern.sub(replace_references, self.content)
-        return markdown(content, extensions=["fenced_code", "attr_list"])
+        return markdown(content, extensions=["fenced_code", "attr_list", "tables"])
 
     @property
     def local_image_references(self) -> set[str]:
@@ -362,6 +362,8 @@ class Blog(object):
             if not blog.image:
                 blog.image = os.path.join("images", "banner" + Path(url.path).suffix)
             blog.download_media(url.geturl(), wordpress, path=blog.image_path)
+        else:
+            featured_media: Medium = None
 
         og_image = next(
             filter(lambda u: wordpress.is_host_for((u)), post.og_images), None
@@ -371,7 +373,7 @@ class Blog(object):
         ):
             if not blog.og_image:
                 blog.og_image = os.path.join(
-                    "images", "og-banner" + Path(url.path).suffix
+                    "images", "og-banner" + Path(og_image.path).suffix
                 )
             blog.download_media(og_image.geturl(), wordpress, blog.og_image_path)
 
@@ -391,6 +393,8 @@ class Blog(object):
             MARKDOWN_EXTENSIONS=[
                 "markdown.extensions.fenced_code",
                 "markdown.extensions.extra",
+                "markdown.extensions.tables",
+                "markdown.extensions.footnotes",
             ],
             code_language_callback=_code_block_language,
         )
