@@ -38,7 +38,7 @@ class ImageType(click.ParamType):
 @click.option("--image", required=False, type=ImageType(), help="for the banner")
 def command(title, subtitle, author, image):
     """
-    frontmatter blog
+    a new frontmatter blog
 
     the index.md will be written in a subdirectory with the name of the slug for the blog.
     The slug is created from the title. The image will be resized and cropped to 1200x630.
@@ -99,20 +99,26 @@ def save_og_image(image: Image, path: Path) -> Path:
     return path
 
 
-@click.command(name="new-og-image")
+@click.command(name="update-banner")
 @click.argument(
     "blog", type=click.Path(exists=True, file_okay=False, readable=True), required=True
 )
-def og_image_command(blog):
+@click.argument(
+    "image", type=ImageType(), required=True
+)
+def update_banner_command(blog, image):
     """
-    for the blog
+    of the blog.
+
+    reads the image, crops it to the 1200x630 dimensions and updates the blog's banner property.
+    Regenerates and updates the og-banner too.
     """
     path = Path(blog).joinpath("index.md")
     if not path.exists():
         raise click.UsageError(f"{path} not found")
 
     blog = Blog.load(path.as_posix())
-    if not blog.image:
-        raise click.UsageError(f"{blog} does not have a banner image yet")
+    image_path = save_og_image(image, blog.dir.joinpath("images/banner"))
+    blog.image = image_path.relative_to(blog.dir).as_posix()
     blog.generate_og_image()
     blog.save()
